Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ChangeSet ¶
type ChangeSet struct {
Data []byte // binary data
Checksum string // md5 sum
Format string // type of the data
Source string // name of the data source
Timestamp time.Time // time stamp
}
ChangeSet represents a set of changes from a source
type Options ¶
type Options struct {
// Encoder
Encoder encoder.Encoder
// for alternative data
Context context.Context
}
func NewOptions ¶
type Source ¶
type Source interface {
Read() (*ChangeSet, error) // read from source, to change set
Watch() (Watcher, error) // watch the source change
String() string // return the name of the data source
}
Source is configure the data source from which the data loader retrieves the raw binary data.
Click to show internal directories.
Click to hide internal directories.